==> haskell-dbus-hslogger-0.1.0.1-572-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-8EX4NdyZfNg2iWqbKJ1wcI
key:                  dbus-hslogger-0.1.0.1-8EX4NdyZfNg2iWqbKJ1wcI
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  6739d967757ae7e20b366e5299f27ca1
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-8EX4NdyZfNg2iWqbKJ1wcI
depends:
    base-4.17.2.1 dbus-1.3.1-Hp9bjklVea09qTBg6NE0I8
    hslogger-1.3.1.2-HizOYagnRFdDuoLuue81te

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dbus-hslogger-0.1.0.1-573-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dbus-hslogger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus-hslogger
version:              0.1.0.1
visibility:           public
id:                   dbus-hslogger-0.1.0.1-8r7ml1gXsTc17KcRq41GA0
key:                  dbus-hslogger-0.1.0.1-8r7ml1gXsTc17KcRq41GA0
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/dbus-hslogger#readme
synopsis:             Expose a dbus server to control hslogger
description:
    Please see the README on Github at <https://github.com/IvanMalison/dbus-hslogger#readme>

category:             System
abi:                  e19fb0c64f3054e0d21e01371e932eb2
exposed:              True
exposed-modules:      System.Log.DBus.Client System.Log.DBus.Server
hidden-modules:       Paths_dbus_hslogger
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dbus-hslogger-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus-hslogger
hs-libraries:         HSdbus-hslogger-0.1.0.1-8r7ml1gXsTc17KcRq41GA0
depends:
    base-4.17.2.1 dbus-1.3.1-Ar8kro93sDpAiMm3tynygZ
    hslogger-1.3.1.2-HizOYagnRFdDuoLuue81te

haddock-interfaces:
    /usr/share/doc/haskell-dbus-hslogger/html/dbus-hslogger.haddock

haddock-html:         /usr/share/doc/haskell-dbus-hslogger/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
